@@ -3,14 +3,17 @@ from .decidir_sdk.DecidirSDK import DecidirSDK
 import os
 
 class SDK:
-    def __init__(self, merchant: dict, merchant_cadena: dict, processor: str = None, marketplace: bool = False):
+    def __init__(self, merchant: dict, merchant_cadena: dict, processor: str = None, marketplace: bool = False, _test = None):
         self._sdk = None
 
         # Se verifica la variable de entorno:
-        test = os.getenv('TEST')
-        test_sdk = True
-        if test.lower() == 'false':
-            test_sdk = False
+        if _test: 
+            test_sdk = _test
+        else:
+            test_env = os.getenv('TEST')
+            test_sdk = True
+            if test_env.lower() == 'false':
+                test_sdk = False
 
         # Se verifica el procesor
         if processor == 'mercadopago':
